<?php
/**
 * File: AdminComments.php
 * Author: tjj
 * Author URI: #
 * Developer: Kamil Głusiński <kamil.glusinski@plawinet.pl>
 * Package: admin_comments_lite
 * Date: 09.08.17
 * Last update: 05.01.2017
 * Plugin Name: Admin Comments
 * Description: Wtyczka blokuje zapisywanie komentarzy przez osoby nieuprawnione.
 * Text Domain: admin-comments
 * Domain Path: /languages
 * Version:     1.1.6
 */
// Tera juz janusze
class AdminComments
{
    private $admin;
    private $add_num_1, $add_num_2;
    private $csrf;

	public function __construct()
    {
        @session_start();
	    $this->init_actions();

        $this->add_num_1 = rand(1, 10);
        $this->add_num_2 = rand(1, 10);
        $this->csrf = substr(md5(mt_rand()), 0, 15);
        $_SESSION[$this->csrf] = (int)$this->add_num_1 + $this->add_num_2;
	}

	/**
	 * Add plugin actions and filters
	 * @return void
	 * @since 1.0.0
     *
	 */
	public function init_actions() {
	    // actions
		add_action('init', function() {
			ob_start();
		});
		add_action( 'plugins_loaded', array($this, 'ac_load_textdomain') );
		add_action( 'wp_head', array( $this, 'ac_process_comment' ) );
		add_action( 'comment_form_after_fields', array($this, 'ac_reconstruct_form') );
		add_action( 'wp_insert_comment', array($this, 'ac_block_spambots'), 99, 2);

		// filters
		add_filter('comment_form_default_fields',array( $this, 'ac_disable_fields' ), 10, 2 );
		add_filter( 'comment_form_submit_button',array( $this, 'ac_reconstruct_submit_btn' ), 10, 2 );

	}

	/**
	 * Translate plugin
	 * @return void
	 * @since 1.0.0
	 *
	 */
	function ac_load_textdomain() {
		load_plugin_textdomain( 'admin-comments', FALSE, dirname(plugin_basename(__FILE__ )). '/languages/' );
	}

	/**
	 * Disables the website field
	 * @return void
	 * @since 1.0.0
	 */
	function ac_disable_fields($fields)
	{
		if(isset($fields['url']))
			unset($fields['url']);
		return $fields;
	}

	/**
	 * Renders a custom form
	 * @return void
	 * @since 1.0.0
	 */
	public function ac_reconstruct_form( $post_id ) {
		if(!current_user_can('administrator')) :

      // Style od pawilnet:
      // (input=number) style="max-width: 50px; width: 100%; color: inherit; background: transparent; border: none; border-radius: 0"
      // (label) style="display: inline; margin-right: 5px"
            ?>
                <p class="comment-form-captcha">
					<label><?php echo $this->add_num_1; ?> + <?php echo $this->add_num_2; ?> = </label>
					<input name="number" value="" class="comment-captcha" type="text">
				</p>
				<input type="hidden" name="csrf" value="<?php echo $this->csrf; ?>">
			<?php
				add_action('wp_footer', function(){
		     ?>

        <?php
				//<script type="text/javascript">
					//var label = document.getElementById('author').previousElementSibling;
					//var color = window.getComputedStyle(label).getPropertyValue("color");
					//document.getElementsByClassName('comment-captcha')[0].style.borderBottom = '1px solid '+color;
				//</script>
        ?>
			<?php
				});

	    endif;
	}

	/**
	 * Renders a custom submit button if not logged in
	 * @return void
	 * @since 1.0.0
	 */
	public function ac_reconstruct_submit_btn( $submit_button, $args ) {
		if(!current_user_can('administrator'))
			return '<input name="submit" id="submit" class="submit" value="'. __('Opublikuj komentarz', 'admin-comments') .'" formaction="" formmethod="POST" type="submit">';
		else
			return $submit_button;
	}

	/**
	 * Comment post handler
	 * @since 1.0.0
	 *
	 */
	public function ac_process_comment() {

		if(isset($_POST['comment_post_ID']) && !current_user_can('administrator')) {
		    ?>
                <?php
                    if(isset($this->ac_validate_form($_POST)['errors'])){
                        add_action('comment_form_top', function(){

                          // Style od pawilnet
                          // (p) style="color: #a94442"
                            ?>
                            <div id="comment-form-msg">
                                <p class="comment-error-title"><strong><?php _e('W formularzu wystąpiły błędy:', 'admin-comments'); ?></strong></p>
                                <?php
                                foreach($this->ac_validate_form($_POST)['errors'] as $error) {
                                    ?>
                                        <p class="comment-error"><?php echo $error; ?></p>
                                    <?php
                                }
                                ?>
                            </div>
                            <?php
                        });
	                    add_action('wp_footer', function(){
		                    ?>
                            <script type="text/javascript">
                                var element_to_scroll_to = document.getElementById('comment-form-msg');
                                element_to_scroll_to.scrollIntoView(true);
                            </script>
		                    <?php
	                    });
                    }
                    else{
	                    wp_redirect(get_permalink().'?post_comment=success');
                    }
                ?>
            <?php

		}
		if(isset($_GET['post_comment']) && !isset($_POST['comment_post_ID']))
        {
	        add_action('comment_form_top', function(){
		        ?>
                <div id="comment-form-msg">
                    <p class="comment-added"><?php _e('Twój komentarz został dodany i czeka na moderację.', 'admin-comments'); ?></p>
                </div>
		        <?php
	        });
	        add_action('wp_footer', function(){
		        ?>
                <script type="text/javascript">
                    var element_to_scroll_to = document.getElementById('comment-form-msg');
                    element_to_scroll_to.scrollIntoView(true);
                </script>
		        <?php
	        });
        }
	}

	/**
	 * Form validation
	 * @since 1.0.0
	 *
	 */
	public function ac_validate_form($data) {
		$errors = array();

	    if(is_user_logged_in())
        {
            $current_user = wp_get_current_user();
	        $name = $current_user->user_login;
	        $email = $current_user->user_email;
        }
        else
        {
	        $name = sanitize_text_field($data['author']);
	        $email = sanitize_text_field($data['email']);

	        $csrf = sanitize_text_field($data['number']);
	        if((int)$csrf != (int)$_SESSION[$data['csrf']])
		        $errors[] = __('Niepoprawne pole captcha.', 'admin-comments');
        }

	    $comment = sanitize_text_field($data['comment']);

	    if($name == '' || $email == '')
	        $errors[] = __('Uzupełnij wszystkie wymagane pola.', 'admin-comments');
	    if($comment == '')
	        $errors[] = __('Komentarz nie może być pusty.', 'admin-comments');
	    if($email != '' && !is_email($email))
	        $errors[] = __('Niepoprawny adres email.', 'admin-comments');

	    if($errors)
	        return(array('errors' => $errors));
	    else
	        return true;
	}

    /**
     * Block directly posting to comments.php like a bots
     * @return void
     * @since 1.1.0
     */
    public function ac_block_spambots($id, $approved)
    {
        if(!current_user_can('administrator')) {
            wp_delete_comment($id, true);
        }
	}
}

$ac= new AdminComments();
// byłem tu januszM
