<?php
/**
 * Nanobrow_base functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Nanobrow_base
 */

/** CMB2 - Activation */
require(get_template_directory().'/inc/CMB2/init.php');

/** Rating metabox in 'Products Post type' - include */
require(get_template_directory().'/metaboxes/rating.php');

/** Rating metabox in 'Single' - include */
require(get_template_directory().'/metaboxes/metabox-single.php');

/** Plugin Activation */
require(get_template_directory().'/functions/plugin-activation/plugin-activation.php');

/** Custom Post Types */
require(get_template_directory().'/functions/custom-post-types.php');

/** Replace content */
require(get_template_directory().'/functions/dkit-replace-content/dkit-replace-content.php');

/** CMB2 Tabs */
require(get_template_directory().'/inc/cmb2-tabs/cmb2-tabs.php');

/** Theme Options - include */
require(get_template_directory().'/metaboxes/theme-options.php');

require(get_template_directory().'/inc/top-products.php');

/** Bootstrap and Jquery Load */
function load_scripts() {
	wp_deregister_script('jquery');
	wp_register_script('jquery', '//code.jquery.com/jquery-3.4.1.min.js', false, null);
	wp_enqueue_script('jquery');
	wp_enqueue_style( 'load-fa', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.6.3/css/font-awesome.min.css' );
	wp_enqueue_script('bootstrap-js', get_template_directory_uri().'/js/bootstrap.js');
	wp_enqueue_style('bootstrap-css', get_template_directory_uri().'/css/bootstrap.css');
}
add_action( 'wp_enqueue_scripts', 'load_scripts' );

function scripts_admin() {
	wp_enqueue_script('jquery');
}
add_action( 'admin_enqueue_scripts', 'scripts_admin' );

/** Load custom scripts */
function enqueue_my_scripts($hook) {
    if ( 'appearance_page_rank' != $hook ) {
        return;
	}
	wp_register_script('jquery-new', '//code.jquery.com/jquery-3.4.1.min.js', false, null);
	wp_enqueue_script('jquery-new');
	wp_enqueue_style('select2-css','//cdn.jsdelivr.net/npm/select2@4.0.12/dist/css/select2.min.css');
	wp_enqueue_script('select2-js', '//cdn.jsdelivr.net/npm/select2@4.0.12/dist/js/select2.min.js');
	wp_enqueue_script('theme-options-js', get_template_directory_uri().'/js/theme-options.js');
	wp_enqueue_style('theme-options-css', get_template_directory_uri().'/css/theme-options.css');
}
add_action( 'admin_enqueue_scripts', 'enqueue_my_scripts' );


if ( ! function_exists( 'nanobrow_base_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function nanobrow_base_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Nanobrow_base, use a find and replace
		 * to change 'nanobrow_base' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'nanobrow_base', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'nanobrow_base' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'nanobrow_base_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'nanobrow_base_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function nanobrow_base_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'nanobrow_base_content_width', 640 );
}
add_action( 'after_setup_theme', 'nanobrow_base_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function nanobrow_base_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'nanobrow_base' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'nanobrow_base' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'nanobrow_base_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function nanobrow_base_scripts() {
	wp_enqueue_style( 'nanobrow_base-style', get_stylesheet_uri() );
	wp_enqueue_script( 'nanobrow_base-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	wp_enqueue_script( 'nanobrow_base-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
}
add_action( 'wp_enqueue_scripts', 'nanobrow_base_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Remove unwanted features.
 */
add_action('init', 'nanobrow_base_remove_post_type_support');
	function nanobrow_base_remove_post_type_support() {
  		remove_post_type_support('post', 'excerpt');
}

/** Excerpt */

/** Excerpt length */
add_filter( 'excerpt_length', function(){
		$excerpt = rank_get_option('excerpt_length_custom');
		return $excerpt;
} );
/** Excerpt link 'read more' */
add_filter( 'excerpt_more', 'new_excerpt_more' );
function new_excerpt_more( $readMore ) {
    global $post;
    $readMore =  __( 'Read More', 'nanobrow_base');
    return '... <a href="'. get_permalink($post) . '">'.$readMore.'</a>';
}
add_filter( 'excerpt_more', 'new_excerpt_more_product' );
function new_excerpt_more_product() {
    global $post;
    $readMore =  __( 'Read More', 'nanobrow_base');
    return '<a href="'. get_permalink($post) . '" class="d-block">'.$readMore.'</a>';
}

/** Pagination arguments */
function theme_nav() {
	$pagination = rank_get_option('pagination');
		if($pagination == 'naviganiton') {
			$args = array(
				'prev_text' => __('Previous'),
				'next_text' => __('Next'),
				'prev_next'    => true,
			);
			$theme_nav = the_posts_navigation($args);
		}
		elseif ($pagination == 'pagination') {
			$args = array(
				'mid_size'  => 3,
				'end_size' => 1,
				'prev_text' => '<',
				'next_text' => '>',
				'prev_next'    => true,
			);
			$theme_nav = the_posts_pagination($args);
		}
		else;
	return $theme_nav;
}
function recommend() {
	global $post;
	$related_tax = 'category';
	$cats_tags_or_taxes = wp_get_object_terms( $post->ID, $related_tax, array( 'fields' => 'ids' ) );
	$args = array(
		'posts_per_page' => rank_get_option('recommended_articles'),
		'post__not_in' => array($post->ID),
		'tax_query' => array(
			array(
				'taxonomy' => $related_tax,
				'field' => 'id',
				'include_children' => false,
				'terms' => $cats_tags_or_taxes,
				'operator' => 'IN'
			)
		)
	);
	$recommend_query = new WP_Query( $args );
	if( $recommend_query->have_posts() ) :
		while( $recommend_query->have_posts() ) : $recommend_query->the_post();
		echo '<div>
		<a href="' . get_permalink( $recommend_query->post->ID ) . '"> <div>'. get_the_post_thumbnail() .'</div><div><h4>  ' . $recommend_query->post->post_title .  '</a></h4>
		<div> ' . get_the_excerpt() . '</div></div></div>';
		endwhile;
	endif;
	wp_reset_postdata();
}

function parse_request_trick( $query ) {

    if ( ! $query->is_main_query() || 2 != count( $query->query ) || ! isset( $query->query['page'] ) ) {
        return;
    }

    if ( ! empty( $query->query['name'] ) ) {
        $query->set( 'post_type', array( 'post', 'products', 'page' ) );
    }
}
add_action( 'pre_get_posts', 'parse_request_trick' );

/** Add custom post type to taxonomies (tag) */
function wpa_cpt_tags( $query ) {
    if ( $query->is_tag() && $query->is_main_query() ) {
        $query->set( 'post_type', array( 'post', 'products' ) );
    }
}
add_action( 'pre_get_posts', 'wpa_cpt_tags' );