<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'dkit_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/CMB2/CMB2
 */

/**
 * Get the bootstrap! If using the plugin from wordpress.org, REMOVE THIS!
 */

if ( file_exists( dirname( __FILE__ ) . '/cmb2/init.php' ) ) {
	require_once dirname( __FILE__ ) . '/cmb2/init.php';
} elseif ( file_exists( dirname( __FILE__ ) . '/CMB2/init.php' ) ) {
	require_once dirname( __FILE__ ) . '/CMB2/init.php';
}

/**
 * Conditionally displays a metabox when used as a callback in the 'show_on_cb' cmb2_box parameter
 *
 * @param  CMB2 $cmb CMB2 object.
 *
 * @return bool      True if metabox should show
 */
function dkit_show_if_front_page___replace_content_plugin( $cmb ) {
	// Don't show this metabox if it's not the front page template.
	if ( get_option( 'page_on_front' ) !== $cmb->object_id ) {
		return false;
	}
	return true;
}

/**
 * Conditionally displays a field when used as a callback in the 'show_on_cb' field parameter
 *
 * @param  CMB2_Field $field Field object.
 *
 * @return bool              True if metabox should show
 */
function dkit_hide_if_no_cats___replace_content_plugin( $field ) {
	// Don't show this field if not in the cats category.
	if ( ! has_tag( 'cats', $field->object_id ) ) {
		return false;
	}
	return true;
}

/**
 * Manually render a field.
 *
 * @param  array      $field_args Array of field arguments.
 * @param  CMB2_Field $field      The field object.
 */
function dkit_render_row_cb___replace_content_plugin( $field_args, $field ) {
	$classes     = $field->row_classes();
	$id          = $field->args( 'id' );
	$label       = $field->args( 'name' );
	$name        = $field->args( '_name' );
	$value       = $field->escaped_value();
	$description = $field->args( 'description' );
	?>
	<div class="custom-field-row <?php echo esc_attr( $classes ); ?>">
		<p><label for="<?php echo esc_attr( $id ); ?>"><?php echo esc_html( $label ); ?></label></p>
		<p><input id="<?php echo esc_attr( $id ); ?>" type="text" name="<?php echo esc_attr( $name ); ?>" value="<?php echo $value; ?>"/></p>
		<p class="description"><?php echo esc_html( $description ); ?></p>
	</div>
	<?php
}

/**
 * Manually render a field column display.
 *
 * @param  array      $field_args Array of field arguments.
 * @param  CMB2_Field $field      The field object.
 */
function dkit_display_text_small_column___replace_content_plugin( $field_args, $field ) {
	?>
	<div class="custom-column-display <?php echo esc_attr( $field->row_classes() ); ?>">
		<p><?php echo $field->escaped_value(); ?></p>
		<p class="description"><?php echo esc_html( $field->args( 'description' ) ); ?></p>
	</div>
	<?php
}

/**
 * Conditionally displays a message if the $post_id is 2
 *
 * @param  array      $field_args Array of field parameters.
 * @param  CMB2_Field $field      Field object.
 */
function dkit_before_row_if_2___replace_content_plugin( $field_args, $field ) {
	if ( 2 == $field->object_id ) {
		echo '<p>Testing <b>"before_row"</b> parameter (on $post_id 2)</p>';
	} else {
		echo '<p>Testing <b>"before_row"</b> parameter (<b>NOT</b> on $post_id 2)</p>';
	}
}



add_action( 'cmb2_admin_init', 'dkit_register_metabox' );
/**
 * Hook in and add a demo metabox. Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */
function dkit_register_metabox() {
    $prefix = 'dkit_';

    /** Get only custom post types */
    $args = array(
        'public' => true,
        '_builtin' => false,
    );

    $post_types = get_post_types( $args );

    $default_posts = array( 'page', 'post');
    $custom_posts = $post_types;

    $merge_posts_arrays = array_merge($default_posts, $custom_posts);

	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox',
		'title'         => esc_html__( 'Zamiana treści', 'cmb2' ),
		'object_types'  => $merge_posts_arrays, // Post type
	) );

    $cmb->add_field( array(
		'name' => esc_html__( 'Tytuł', 'cmb2' ),
		'desc' => esc_html__( 'Można używać znaczników HTML, np.: "Tytuł z <b>pogrubionym</b> tekstem". Uwaga - wpisany tytuł zastąpi domyślny tytuł.', 'cmb2' ),
		'id'   => $prefix . 'new_title',
		'type' => 'textarea_small',
	) );

    $cmb->add_field( array(
		'name'    => esc_html__( 'Treść', 'cmb2' ),
		'desc'    => esc_html__( 'Uwaga - wpisana treść zastąpi domyślną treść.', 'cmb2' ),
		'id'      => $prefix . 'new_content',
		'type'    => 'wysiwyg',
		'options' => array(
            'textarea_rows' => 18,
		),
        ) );

    $cmb->add_field( array(
        'name'    => esc_html__( 'Zajawka', 'cmb2' ),
        'desc'    => esc_html__( 'Uwaga - wpisana zajawka zastąpi domyślną zajawkę.', 'cmb2' ),
        'id'      => $prefix . 'new_excerpt',
        'type'    => 'wysiwyg',
        'options' => array(
            'textarea_rows' => 8,
        ),
    ) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Zamień treści', 'cmb2' ),
		'desc' => esc_html__( 'Dotychczasowa treść zostanie zastąpiona', 'cmb2' ),
		'id'   => $prefix . 'accept_content_replacement',
		'type' => 'checkbox',
	) );
}